@@ -54,22 +54,24 @@ class Experiment:
         """Load all databases specified in the configuration and map the labels"""
         ds = ast.literal_eval(glob_conf.config['DATA']['databases'])
         self.datasets = {}
-        self.got_speaker, self.got_gender = False, False
+        self.got_speaker, self.got_gender, self.got_age = False, False, False
         for d in ds:
-            if d == 'ravdess':
-                data = Ravdess()
+            # if d == 'ravdess':
+            #     data = Ravdess()
+            # else:
+            ds_type = self.util.config_val_data(d, 'type', 'audformat')
+            if ds_type == 'audformat':
+                data = Dataset(d)
+            elif ds_type == 'csv':
+                data = Dataset_CSV(d)
             else:
-                ds_type = self.util.config_val_data(d, 'type', 'audformat')
-                if ds_type == 'audformat':
-                    data = Dataset(d)
-                elif ds_type == 'csv':
-                    data = Dataset_CSV(d)
-                else:
-                    self.util.error(f'unknown data type: {ds_type}')
+                self.util.error(f'unknown data type: {ds_type}')
             data.load()
 #            data.prepare()
             if data.got_gender:
                 self.got_gender = True
+            if data.got_age:
+                self.got_age = True
             if data.got_speaker:
                 self.got_speaker = True
             self.datasets.update({d: data})
@@ -110,6 +112,8 @@ class Experiment:
                 data.load()
                 if data.got_gender:
                     self.got_gender = True
+                if data.got_age:
+                    self.got_age = True
                 if data.got_speaker:
                     self.got_speaker = True
                 data.prepare_labels()
@@ -170,9 +174,11 @@ class Experiment:
             self.df_train.to_csv(storage_train)
 
         self.df_train.got_gender = self.got_gender
+        self.df_train.got_age = self.got_age
         self.df_train.got_speaker = self.got_speaker
         self.df_test.got_gender = self.got_gender
         self.df_test.got_speaker = self.got_speaker
+        self.df_test.got_age = self.got_age
 
         # Check for filters
         min_dur_test = self.util.config_val('DATA', 'min_dur_test', False)
@@ -437,5 +443,5 @@ class Experiment:
             f = open(filename, 'wb')
             pickle.dump(self.__dict__, f)
             f.close()
-        except AttributeError: 
-            self.util.error('Save experiment: Can\'t pickle local object')
\ No newline at end of file
+        except (AttributeError, TypeError) as error: 
+            self.util.debug(f'Save experiment: Can\'t pickle local object: {error}')
\ No newline at end of file
